@@ -1,9 +1,10 @@
 package Data::ModeMerge::Config;
 
-use 5.010;
-use Moo;
+our $DATE = '2015-02-21'; # DATE
+our $VERSION = '0.31'; # VERSION
 
-our $VERSION = '0.30'; # VERSION
+use 5.010;
+use Mo qw(build default);
 
 has recurse_hash          => (is => 'rw', default => sub{1});
 has recurse_array         => (is => 'rw', default => sub{0});
@@ -70,17 +71,19 @@ sub _config_ok {
 1;
 # ABSTRACT: Data::ModeMerge configuration
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Data::ModeMerge::Config - Data::ModeMerge configuration
 
 =head1 VERSION
 
-version 0.30
+This document describes version 0.31 of Data::ModeMerge::Config (from Perl distribution Data-ModeMerge), released on 2015-02-21.
 
 =head1 SYNOPSIS
 
@@ -156,15 +159,15 @@ Example:
  mode_merge(
    {
     user => {
-      steven => { quota => 100, admin => 1 },
-      tommie => { quota =>  50, admin => 0 },
-      jimmy  => { quota => 150, admin => 0 },
+      jajang => { quota => 100, admin => 1 },
+      paijo  => { quota =>  50, admin => 0 },
+      kuya   => { quota => 150, admin => 0 },
     },
     groups => [qw/admin staff/],
    },
    {
     user => {
-      steven => { quota => 1000 },
+      jajang => { quota => 1000 },
     }
    }
  );
@@ -173,20 +176,20 @@ With wanted_path unset, the result would be:
 
    {
     user => {
-      steven => { quota => 1000, admin => 1 },
-      tommie => { quota =>   50, admin => 0 },
-      jimmy  => { quota =>  150, admin => 0 },
+      jajang => { quota => 1000, admin => 1 },
+      paijo  => { quota =>   50, admin => 0 },
+      kuya   => { quota =>  150, admin => 0 },
     }
     groups => [qw/admin staff/],
    }
 
-With wanted_path set to ["user", "steven", "quota"] (in other words,
+With wanted_path set to ["user", "jajang", "quota"] (in other words,
 you're saying that you'll be disregarding other branches), the result
 would be:
 
    {
     user => {
-      steven => { quota => 1000, admin => undef },
+      jajang => { quota => 1000, admin => undef },
     }
    }
 
@@ -491,16 +494,31 @@ If C<disallow_override> is also set, then only config names matching
 C<allow_override> and not matching C<disallow_override> will be able
 to be set in options key.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Data-ModeMerge>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Data-ModeMerge>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-ModeMerge>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
