@@ -1,13 +1,17 @@
 package Data::ModeMerge::Mode::Base;
 
+our $DATE = '2015-02-21'; # DATE
+our $VERSION = '0.31'; # VERSION
+
 use 5.010;
-use Log::Any '$log';
-use Moo;
+use strict;
+use warnings;
+
+#use Log::Any '$log';
+use Mo qw(build default);
 
 #use Data::Clone qw/clone/;
 
-our $VERSION = '0.30'; # VERSION
-
 has merger => (is => 'rw');
 has prefix => (is => 'rw');
 has prefix_re => (is => 'rw');
@@ -568,17 +572,19 @@ sub merge_HASH_HASH {
 1;
 # ABSTRACT: Base class for Data::ModeMerge mode handler
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Data::ModeMerge::Mode::Base - Base class for Data::ModeMerge mode handler
 
 =head1 VERSION
 
-version 0.30
+This document describes version 0.31 of Data::ModeMerge::Mode::Base (from Perl distribution Data-ModeMerge), released on 2015-02-21.
 
 =head1 SYNOPSIS
 
@@ -635,16 +641,31 @@ Return hash key with added prefix of this mode.
 
 Return hash key with prefix of this mode prefix removed.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Data-ModeMerge>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Data-ModeMerge>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-ModeMerge>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
